API docs for “spamfighter.core.commands.apiglue.API_Glue”

# Class s.c.c.a.API_Glue:

Part of spamfighter.core.commands.apiglue View Source View In Hierarchy

Known subclasses: spamfighter.core.commands.apiglue.JSONRPC_API_Glue, spamfighter.core.commands.apiglue.XMLRPC_API_Glue

Базовый класс, обеспечивающий связь XML-RPC и JSON-RPC реализаций на базе Twisted.Web с нашей системой команд.

Данный вариант является базовым и зависит от типа используемого преобразователя ошибок (для XML-RPC или JSON-RPC).

Method | _internalGetFunction | Получить функцию, выполняющую команду с указанным именем и при этом

def _internalGetFunction(self, error_translator, functionPath): (source)
Получить функцию, выполняющую команду с указанным именем и при этом использующую указанный механизм преобразования ошибок.

Parameters | error_translator | преобразователь ошибок
| functionPath | имя функции (полное, как путь) (type: `str` )
Returns | функция, которая принимает параметры команды и возвращает Deferred на её результат